/*-----------------------------------------------------------------------------
 *
 * Enhydra JdbcS
 * The Initial Developer of the Original Code is Lutris Technologies Inc.
 * Portions created by Lutris are Copyright 1997-2000 Lutris Technologies Inc.
 * All Rights Reserved.
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * www.enhydra.org/license/epl.html
 *
 * Software distributed under the License is distributed on an "ASIS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * -----------------------------------------------------------------------------
 */
package org.enhydra.jdbc.standard;

import java.sql.SQLException;

public class StandardXAPreparedStatement extends StandardPreparedStatement {

	private StandardXAConnectionHandle con;
	// the StandardXAConnectionHandle that created this object
	public String sql;
	public int resultSetType;
	public int resultSetConcurrency;

	StandardXAPreparedStatement(
		StandardXAConnectionHandle con_,
		String sql_,
		int resultSetType_,
		int resultSetConcurrency_)
		throws SQLException {
		this.con = con_;
		this.sql = sql_;
		this.key = sql_ + resultSetType_ + resultSetConcurrency_;
		this.resultSetType = resultSetType_;
		this.resultSetConcurrency = resultSetConcurrency_;
		log = con_.log;
		log.debug(
			"StandardXAPreparedStatement: Create an XAPreparedStatement with sql='"
				+ sql
				+ "'");

		key =
			sql
				+ resultSetType
				+ resultSetConcurrency
				+ ((con.tx != null) ? true : false);
		ps =
			con.checkPreparedCache(
				sql,
				resultSetType,
				resultSetConcurrency,
				key);
		// from cney
		// ps = con.checkPreparedCache(sql, resultSetType, resultSetConcurrency,key);
	}

	/**
	 * Close this statement.
	 */
	public synchronized void close() throws SQLException {
		log.debug(
			"StandardXAPreparedStatement:close the XA prepared statement");
		// Note no check for already closed - some servers make mistakes
		closed = true;
		if (con.preparedStmtCacheSize == 0) {
			log.debug(
				"StandardXAPreparedStatement:close preparedStmtCacheSize == 0");
			if (ps != null) {
				ps.close(); // no cache, so we can close
			}
		} else {
			log.debug(
				"StandardXAPreparedStatement:close preparedStmtCacheSize="
					+ "'"
					+ con.preparedStmtCacheSize
					+ "'");
			con.returnToCache(key);
			// return the underlying statement to the cache
		}
	}


	/**
	 * Exception management : catch or throw the exception
	 */
	public void catchInvoke(SQLException sqlException) throws SQLException {
		//ConnectionEvent event = new ConnectionEvent (con.pooledCon);
		//con.pooledCon.connectionErrorOccurred(event);
		throw (sqlException);
	}

}
